# SAP LeanIX Architecture and Road Map Planning
### On this page
  * [Overview](https://help.sap.com/docs/leanix/ea/sap-leanix-architecture-and-road-map-planning#overview)
  * [Key Capabilities of SAP LeanIX Architecture and Road Map Planning](https://help.sap.com/docs/leanix/ea/sap-leanix-architecture-and-road-map-planning#key-capabilities-of-sap-leanix-architecture-and-road-map-planning)
  * [Introduction to SAP LeanIX Architecture and Road Map Planning](https://help.sap.com/docs/leanix/ea/sap-leanix-architecture-and-road-map-planning#introduction-to-sap-leanix-architecture-and-road-map-planning)
  * [Transformation Insights from SAP LeanIX Architecture and Road Map Planning](https://help.sap.com/docs/leanix/ea/sap-leanix-architecture-and-road-map-planning#transformation-insights-from-sap-leanix-architecture-and-road-map-planning)


The SAP LeanIX Architecture and Road Map Planning enhances SAP LeanIX Application Portfolio Management by offering advanced features for seamless planning and execution of transformation initiatives in enterprise architecture management.
